@@ -4,12 +4,8 @@
 
 import logging
 
-try:
-    from logging import NullHandler
-except ImportError:
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
+from logging import NullHandler
+
 
 logger = logging.getLogger(__name__)
 logger.addHandler(NullHandler())
